cslint-cli-0.1.0 is not a library.
CLI entry point for the cslint constraint-system linter.
Reads an ACIR bytecode file, lowers it to the core IR, runs all four heuristic analyses, and prints the results.
CLI entry point for the cslint constraint-system linter.
Reads an ACIR bytecode file, lowers it to the core IR, runs all four heuristic analyses, and prints the results.